@@ -21,6 +21,8 @@ class GlobalOptions:
         "config",
         "verbose",
         "quiet",
+        "log_timestamps",
+        "compact",
     )
     json: bool
     rules: Tuple[TextIO, ...]
@@ -36,6 +38,8 @@ class GlobalOptions:
     config: Optional[TextIO]
     verbose: int
     quiet: bool
+    log_timestamps: bool
+    compact: bool
 
 
 @dataclass
@@ -48,8 +52,8 @@ class GitOptions:
 
 
 class IssueType(enum.Enum):
-    Entropy = "High Entropy"
-    RegEx = "Regular Expression Match"
+    Entropy = "High Entropy"  # pylint: disable=invalid-name
+    RegEx = "Regular Expression Match"  # pylint: disable=invalid-name
 
 
 @dataclass
@@ -68,6 +72,13 @@ class Rule:
     path_pattern: Optional[Pattern]
 
 
+class LogLevel(enum.IntEnum):
+    ERROR = 0
+    WARNING = 1
+    INFO = 2
+    DEBUG = 3
+
+
 class TartufoException(Exception):
     """Base class for all package exceptions"""
 
